import React, { useContext, useState, useRef, useEffect } from 'react';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var TransformContext = /*#__PURE__*/React.createContext({
  scale: 1,
  offsetX: 0,
  offsetY: 0,
  setScale: function setScale() {},
  setOffsetX: function setOffsetX() {},
  setOffsetY: function setOffsetY() {}
});
TransformContext.displayName = 'TransformContext';
/**
 * Hook to provide the transform context
 */

var useTransform = function useTransform() {
  return useContext(TransformContext);
};
var TransformConsumer = TransformContext.Consumer;

var TransformProvider = function TransformProvider(_ref) {
  var children = _ref.children,
      _ref$initialScale = _ref.initialScale,
      initialScale = _ref$initialScale === void 0 ? 1 : _ref$initialScale;

  var _useState = useState(initialScale),
      scale = _useState[0],
      setScale = _useState[1];

  var _useState2 = useState(0),
      offsetX = _useState2[0],
      setOffsetX = _useState2[1];

  var _useState3 = useState(0),
      offsetY = _useState3[0],
      setOffsetY = _useState3[1];

  return React.createElement(TransformContext.Provider, {
    value: {
      scale: scale,
      offsetX: offsetX,
      offsetY: offsetY,
      setScale: setScale,
      setOffsetY: setOffsetY,
      setOffsetX: setOffsetX
    }
  }, children);
};

/**
 * The component that takes the transform context and applies it
 */

var TransformComponent = function TransformComponent(_ref) {
  var children = _ref.children,
      style = _ref.style,
      className = _ref.className;

  var _useTransform = useTransform(),
      scale = _useTransform.scale,
      setScale = _useTransform.setScale,
      offsetX = _useTransform.offsetX,
      setOffsetX = _useTransform.setOffsetX,
      offsetY = _useTransform.offsetY,
      setOffsetY = _useTransform.setOffsetY;

  var elementRef = useRef(null);
  useEffect(function () {
    var el = elementRef.current;

    var onWheel = function onWheel(e) {
      e.preventDefault();

      if (e.ctrlKey) {
        // Your zoom/scale factor
        setScale(Math.max(0.2, scale - e.deltaY * 0.01));
      } else {
        // The trackpad is panning
        setOffsetX(offsetX - e.deltaX * 2);
        setOffsetY(offsetY - e.deltaY * 2);
      }
    };

    el === null || el === void 0 ? void 0 : el.addEventListener('wheel', onWheel, {
      passive: false
    });
    return function () {
      el === null || el === void 0 ? void 0 : el.removeEventListener('wheel', onWheel);
    };
  }, [offsetX, offsetY, scale, setOffsetX, setOffsetY, setScale]);
  return React.createElement("div", {
    ref: elementRef,
    style: style,
    className: className
  }, React.createElement("div", {
    style: {
      transform: "scale(" + scale + ") translateX(" + offsetX + "px) translateY(" + offsetY + "px)"
    }
  }, children));
};

/**
 * All in one component that provides pinch, zoom, and pan capabilities
 */

var PinchNZoom = function PinchNZoom(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return React.createElement(TransformProvider, null, React.createElement(TransformComponent, Object.assign({}, props), children));
};

export default PinchNZoom;
export { TransformComponent, TransformConsumer, TransformProvider, useTransform };
//# sourceMappingURL=react-pinch-n-zoom.esm.js.map
